package com.antai.sport.http.server.game.api.business.sport.user;


import com.antai.sport.http.server.common.base.Result;
import com.antai.sport.http.server.common.exception.BusinessException;
import com.antai.sport.http.server.constants.DeleteStatus;
import com.antai.sport.http.server.constants.LoginMode;
import com.antai.sport.http.server.game.api.business.sport.user.dto.ReqLogin;
import com.antai.sport.http.server.repository.sport.entity.SportUser;
import com.antai.sport.http.server.repository.sport.mapper.SportUserMapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.DigestUtils;

import javax.annotation.Resource;
import java.util.List;

/**
 * @Author liming
 * @Date 2021/8/21 19:41
 * @Email lmmax@126.com
 * @Description:
 */
@Service
public class SportUserService {

    @Resource
    private SportUserMapper sportUserMapper;

    public Result login(ReqLogin param) {
        if (param.getMode() == null || (!param.getMode().equals(LoginMode.PASSWORD) && !param.getMode().equals(LoginMode.SMS_CAPTCHA))) {
            throw new BusinessException("请选择正确的登录模式");
        }
        if (StringUtils.isBlank(param.getUsername())) {
            throw new BusinessException("请输入用户名");
        }
        List<SportUser> sportUserList = sportUserMapper.selectList(new QueryWrapper<SportUser>()
                .eq("phone", param.getUsername())
                .eq("deleted", DeleteStatus.UNDELETED));
        if (sportUserList.isEmpty()) {
            throw new BusinessException("用户名或密码错误");
        }
        SportUser sportUser = sportUserList.get(0);

        Result result = new Result();
        if (param.getMode().equals(LoginMode.PASSWORD)) {
            if (sportUser.getPassword() == null) {
                throw new BusinessException("当前用户还没有设置密码，请使用验证码方式登录");
            }
            if (StringUtils.isBlank(param.getPassword())) {
                throw new BusinessException("请输入密码");
            }
            String hashPwd = DigestUtils.md5DigestAsHex(param.getPassword().getBytes());
            if (hashPwd.equals(sportUser.getPassword())) {
                result.setRespMsg("登录成功");
                result.setData(true);
            } else {
                throw new BusinessException("用户名或密码错误");
            }
        } else {
            if (StringUtils.isBlank(param.getSmsCaptcha())) {
                throw new BusinessException("请输入验证码");
            }
        }
        return result;
    }

}
